@@ -348,6 +348,38 @@ context 'Manpage' do
       assert_includes output, %(Oh, here it goes again\nI should have known,\nshould have known,\nshould have known again)
     end
 
+    test 'should escape repeated spaces in literal content' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      ....
+      \x20 ,---.          ,-----.
+      \x20 |Bob|          |Alice|
+      \x20 `-+-'          `--+--'
+      \x20   |    hello      |
+      \x20   |-------------->|
+      \x20 ,-+-.          ,--+--.
+      \x20 |Bob|          |Alice|
+      \x20 `---'          `-----'
+      ....
+      EOS
+
+      output = Asciidoctor.convert input, backend: :manpage
+      expects = <<~'EOS'.lines.map {|it| (' ' * it.chr.to_i) + (it.slice 1, it.length) }.join
+      0.fam C
+      2,\-\-\-.\&          ,\-\-\-\-\-.
+      2|Bob|\&          |Alice|
+      2`\-+\-\*(Aq\&          `\-\-+\-\-\*(Aq
+      4|\&    hello\&      |
+      4|\-\-\-\-\-\-\-\-\-\-\-\-\-\->|
+      2,\-+\-.\&          ,\-\-+\-\-.
+      2|Bob|\&          |Alice|
+      2`\-\-\-\*(Aq\&          `\-\-\-\-\-\*(Aq
+      0.fam
+      EOS
+      assert_includes output, expects
+    end
+
     test 'should preserve break between paragraphs in normal table cell' do
       input = <<~EOS.chop
       #{SAMPLE_MANPAGE_HEADER}
@@ -818,7 +850,7 @@ context 'Manpage' do
       .sp
       .nf
       b
-      c    _d_
+      c\&    _d_
       \&.
       .fi
       T}
